Struct NodeCapabilities
pub struct NodeCapabilities(/* private fields */);Implementations
impl NodeCapabilities
impl NodeCapabilities
pub const REPEATER: NodeCapabilities
pub const MOBILE: NodeCapabilities
pub const TEXT_MESSAGES: NodeCapabilities
pub const TELEMETRY: NodeCapabilities
pub const CHAT_ROOM: NodeCapabilities
pub const COAP: NodeCapabilities
impl NodeCapabilities
impl NodeCapabilities
pub const fn empty() -> NodeCapabilities
pub const fn empty() -> NodeCapabilities
Get a flags value with all bits unset.
pub const fn all() -> NodeCapabilities
pub const fn all() -> NodeCapabilities
Get a flags value with all known bits set.
pub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u8) -> Option<NodeCapabilities>
pub const fn from_bits(bits: u8) -> Option<NodeCapabilities>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u8) -> NodeCapabilities
pub const fn from_bits_truncate(bits: u8) -> NodeCapabilities
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u8) -> NodeCapabilities
pub const fn from_bits_retain(bits: u8) -> NodeCapabilities
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<NodeCapabilities>
pub fn from_name(name: &str) -> Option<NodeCapabilities>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: NodeCapabilities) -> bool
pub const fn intersects(&self, other: NodeCapabilities) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
pub const fn contains(&self, other: NodeCapabilities) -> bool
pub const fn contains(&self, other: NodeCapabilities) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
pub fn insert(&mut self, other: NodeCapabilities)
pub fn insert(&mut self, other: NodeCapabilities)
The bitwise or (|) of the bits in two flags values.
pub fn remove(&mut self, other: NodeCapabilities)
pub fn remove(&mut self, other: NodeCapabilities)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: NodeCapabilities)
pub fn toggle(&mut self, other: NodeCapabilities)
The bitwise exclusive-or (^) of the bits in two flags values.
pub fn set(&mut self, other: NodeCapabilities, value: bool)
pub fn set(&mut self, other: NodeCapabilities, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: NodeCapabilities) -> NodeCapabilities
pub const fn intersection(self, other: NodeCapabilities) -> NodeCapabilities
The bitwise and (&) of the bits in two flags values.
pub const fn union(self, other: NodeCapabilities) -> NodeCapabilities
pub const fn union(self, other: NodeCapabilities) -> NodeCapabilities
The bitwise or (|) of the bits in two flags values.
pub const fn difference(self, other: NodeCapabilities) -> NodeCapabilities
pub const fn difference(self, other: NodeCapabilities) -> NodeCapabilities
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: NodeCapabilities,
) -> NodeCapabilities
pub const fn symmetric_difference( self, other: NodeCapabilities, ) -> NodeCapabilities
The bitwise exclusive-or (^) of the bits in two flags values.
pub const fn complement(self) -> NodeCapabilities
pub const fn complement(self) -> NodeCapabilities
The bitwise negation (!) of the bits in a flags value, truncating the result.
impl NodeCapabilities
impl NodeCapabilities
pub const fn iter(&self) -> Iter<NodeCapabilities>
pub const fn iter(&self) -> Iter<NodeCapabilities>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<NodeCapabilities>
pub const fn iter_names(&self) -> IterNames<NodeCapabilities>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.