SendToken

Struct SendToken 

pub struct SendToken {
    pub identity_id: LocalIdentityId,
    pub receipt: SendReceipt,
}
Identity-scoped send token.

[SendReceipt] is only unique within a LocalIdentityId slot (it’s allocated from a per-identity next_receipt counter). SendToken combines the two into a single value that is unique across all identity slots, suitable for use as a dispatcher key, ticket identifier, or cancellation handle.

Fields

identity_id: LocalIdentityIdreceipt: SendReceipt

Implementations



impl SendToken

pub fn new(identity_id: LocalIdentityId, receipt: SendReceipt) -> SendToken

Create a new send token from an identity slot and receipt.