UlcpDeviceConfig

Struct UlcpDeviceConfig 

pub struct UlcpDeviceConfig {
    pub freq_khz: u32,
    pub bandwidth_hz: u32,
    pub spreading_factor: u8,
    pub coding_rate_denom: u8,
    pub tx_power_dbm: i8,
    pub sync_word: u16,
    pub response_timeout: Duration,
}
RF and session configuration applied during initialization.

Fields

freq_khz: u32

Center frequency in kHz (PROP_PHY_FREQ).

bandwidth_hz: u32

LoRa bandwidth in Hz (PROP_PHY_LORA_BW).

spreading_factor: u8

LoRa spreading factor, 5-12 (PROP_PHY_LORA_SF).

coding_rate_denom: u8

LoRa coding-rate denominator: 5 for 4/5 through 8 for 4/8 (PROP_PHY_LORA_CR).

tx_power_dbm: i8

Transmit power in dBm (PROP_PHY_TX_POWER).

sync_word: u16

SX126x-style 16-bit sync word (PROP_PHY_LORA_SW).

response_timeout: Duration

How long to wait for the device to answer one command, excluding airtime (transmit confirmations extend this by the frame airtime).

Implementations

Source

impl UlcpDeviceConfig

pub fn new( freq_khz: u32, bandwidth_hz: u32, spreading_factor: u8, coding_rate_denom: u8, ) -> Self

Configuration with the given RF link parameters, 0 dBm transmit power, the suggested default sync word, and a 2-second response timeout.