Enum PayloadType
#[repr(u8)]pub enum PayloadType {
Empty = 255,
Unspecified = 0,
NodeIdentity = 1,
MacCommand = 2,
TextMessage = 3,
ChatRoomMessage = 5,
CoapOverUmsh = 7,
NodeManagement = 8,
}Expand description
Application payload type carried inside the MAC body.
Empty is a special out-of-band value used when the frame carries no
application payload bytes at all, meaning there is no payload-type byte on
the wire. All other variants correspond to the leading typed-payload byte.
Variants
Empty = 255
No application payload and no payload-type byte on the wire.
Unspecified = 0
Explicit application-agnostic payload type byte 0.
NodeIdentity = 1
Node-identity payload.
MacCommand = 2
MAC command payload.
TextMessage = 3
Text-message payload.
ChatRoomMessage = 5
Chat-room management payload.
CoapOverUmsh = 7
CoAP-over-UMSH payload.
NodeManagement = 8
Node-management payload.
Implementations
impl PayloadType
impl PayloadType
pub fn from_byte(byte: u8) -> Option<PayloadType>
pub fn from_byte(byte: u8) -> Option<PayloadType>
Convert a raw payload-type byte into a known payload type.
pub fn allowed_for(self, packet_type: PacketType) -> bool
pub fn allowed_for(self, packet_type: PacketType) -> bool
Return whether this payload type is valid for the given MAC packet type.